The most effective remediation against NoSQL injection attacks is to
ensure that NoSQL API calls are not constructed via string
concatenation that includes unsanitized data.

Sanitization is best achieved using existing escaping libraries.